==> aria2_1.15.1.orig.tar.bz2: aria2-1.15.1/src/SeedCheckCommand.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_SEED_CHECK_COMMAND_H
#define D_SEED_CHECK_COMMAND_H

#include "Command.h"
#include "SharedHandle.h"

namespace aria2 {

class RequestGroup;
class DownloadEngine;
class SeedCriteria;
class BtRuntime;
class PieceStorage;

class SeedCheckCommand : public Command
{
private:
  RequestGroup* requestGroup_;
  DownloadEngine* e_;
  SharedHandle<PieceStorage> pieceStorage_;
  SharedHandle<BtRuntime> btRuntime_;
  SharedHandle<SeedCriteria> seedCriteria_;
  bool checkStarted_;
public:
  SeedCheckCommand(cuid_t cuid,
                   RequestGroup* requestGroup,
                   DownloadEngine* e,
                   const SharedHandle<SeedCriteria>& seedCriteria);

  virtual ~SeedCheckCommand();

  virtual bool execute();

  void setSeedCriteria(const SharedHandle<SeedCriteria>& seedCriteria);

  void setBtRuntime(const SharedHandle<BtRuntime>& btRuntime);

  void setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage);
};

} // namespace aria2

#endif // D_SEED_CHECK_COMMAND_H

==> aria2_1.18.1.orig.tar.bz2: aria2-1.18.1/src/SeedCheckCommand.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_SEED_CHECK_COMMAND_H
#define D_SEED_CHECK_COMMAND_H

#include "Command.h"

#include <memory>

namespace aria2 {

class RequestGroup;
class DownloadEngine;
class SeedCriteria;
class BtRuntime;
class PieceStorage;

class SeedCheckCommand : public Command
{
private:
  RequestGroup* requestGroup_;
  DownloadEngine* e_;
  std::shared_ptr<PieceStorage> pieceStorage_;
  std::shared_ptr<BtRuntime> btRuntime_;
  std::unique_ptr<SeedCriteria> seedCriteria_;
  bool checkStarted_;
public:
  SeedCheckCommand(cuid_t cuid,
                   RequestGroup* requestGroup,
                   DownloadEngine* e,
                   std::unique_ptr<SeedCriteria> seedCriteria);

  virtual ~SeedCheckCommand();

  virtual bool execute() CXX11_OVERRIDE;

  void setBtRuntime(const std::shared_ptr<BtRuntime>& btRuntime);

  void setPieceStorage(const std::shared_ptr<PieceStorage>& pieceStorage);
};

} // namespace aria2

#endif // D_SEED_CHECK_COMMAND_H
